redis

package
v0.0.0-...-1bf35a1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2020 License: MIT Imports: 3 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Redis_c

type Redis_c struct {
	TestingFlag bool
	// contains filtered or unexported fields
}

func (*Redis_c) Check

func (r *Redis_c) Check(mainFlag bool) error

! \brief Sets up all the connection pools that we'll need in the future

func (*Redis_c) Close

func (r *Redis_c) Close()

func (*Redis_c) Connect

func (r *Redis_c) Connect(ip string, port int) (err error)

func (*Redis_c) Subordinateof

func (r *Redis_c) Subordinateof(ip, port string) error

! \brief Tells the redis server who it should be a subordinate of

Jump to