package
Version:
v0.0.0-...-1bf35a1
Opens a new window with list of versions in this module.
Published: Jul 23, 2020
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type Redis_c struct {
TestingFlag bool
}
! \brief Sets up all the connection pools that we'll need in the future
! \brief Tells the redis server who it should be a subordinate of
Source Files
¶
Click to show internal directories.
Click to hide internal directories.